@@ -404,6 +404,65 @@
 #define __NR_copy_file_range		(__NR_SYSCALL_BASE+391)
 #define __NR_preadv2			(__NR_SYSCALL_BASE+392)
 #define __NR_pwritev2			(__NR_SYSCALL_BASE+393)
+#define __NR_pkey_mprotect (__NR_SYSCALL_BASE + 394)
+#define __NR_pkey_alloc (__NR_SYSCALL_BASE + 395)
+#define __NR_pkey_free (__NR_SYSCALL_BASE + 396)
+#define __NR_statx (__NR_SYSCALL_BASE + 397)
+#define __NR_rseq (__NR_SYSCALL_BASE + 398)
+#define __NR_io_pgetevents (__NR_SYSCALL_BASE + 399)
+#define __NR_migrate_pages (__NR_SYSCALL_BASE + 400)
+#define __NR_kexec_file_load (__NR_SYSCALL_BASE + 401)
+#define __NR_clock_gettime64 (__NR_SYSCALL_BASE + 403)
+#define __NR_clock_settime64 (__NR_SYSCALL_BASE + 404)
+#define __NR_clock_adjtime64 (__NR_SYSCALL_BASE + 405)
+#define __NR_clock_getres_time64 (__NR_SYSCALL_BASE + 406)
+#define __NR_clock_nanosleep_time64 (__NR_SYSCALL_BASE + 407)
+#define __NR_timer_gettime64 (__NR_SYSCALL_BASE + 408)
+#define __NR_timer_settime64 (__NR_SYSCALL_BASE + 409)
+#define __NR_timerfd_gettime64 (__NR_SYSCALL_BASE + 410)
+#define __NR_timerfd_settime64 (__NR_SYSCALL_BASE + 411)
+#define __NR_utimensat_time64 (__NR_SYSCALL_BASE + 412)
+#define __NR_pselect6_time64 (__NR_SYSCALL_BASE + 413)
+#define __NR_ppoll_time64 (__NR_SYSCALL_BASE + 414)
+#define __NR_io_pgetevents_time64 (__NR_SYSCALL_BASE + 416)
+#define __NR_recvmmsg_time64 (__NR_SYSCALL_BASE + 417)
+#define __NR_mq_timedsend_time64 (__NR_SYSCALL_BASE + 418)
+#define __NR_mq_timedreceive_time64 (__NR_SYSCALL_BASE + 419)
+#define __NR_semtimedop_time64 (__NR_SYSCALL_BASE + 420)
+#define __NR_rt_sigtimedwait_time64 (__NR_SYSCALL_BASE + 421)
+#define __NR_futex_time64 (__NR_SYSCALL_BASE + 422)
+#define __NR_sched_rr_get_interval_time64 (__NR_SYSCALL_BASE + 423)
+#define __NR_pidfd_send_signal (__NR_SYSCALL_BASE + 424)
+#define __NR_io_uring_setup (__NR_SYSCALL_BASE + 425)
+#define __NR_io_uring_enter (__NR_SYSCALL_BASE + 426)
+#define __NR_io_uring_register (__NR_SYSCALL_BASE + 427)
+#define __NR_open_tree (__NR_SYSCALL_BASE + 428)
+#define __NR_move_mount (__NR_SYSCALL_BASE + 429)
+#define __NR_fsopen (__NR_SYSCALL_BASE + 430)
+#define __NR_fsconfig (__NR_SYSCALL_BASE + 431)
+#define __NR_fsmount (__NR_SYSCALL_BASE + 432)
+#define __NR_fspick (__NR_SYSCALL_BASE + 433)
+#define __NR_pidfd_open (__NR_SYSCALL_BASE + 434)
+#define __NR_clone3 (__NR_SYSCALL_BASE + 435)
+#define __NR_openat2 (__NR_SYSCALL_BASE + 437)
+#define __NR_pidfd_getfd (__NR_SYSCALL_BASE + 438)
+#define __NR_faccessat2 (__NR_SYSCALL_BASE + 439)
+#define __NR_process_madvise (__NR_SYSCALL_BASE + 440)
+#define __NR_epoll_pwait2 (__NR_SYSCALL_BASE + 441)
+#define __NR_mount_setattr (__NR_SYSCALL_BASE + 442)
+#define __NR_quotactl_fd (__NR_SYSCALL_BASE + 443)
+#define __NR_landlock_create_ruleset (__NR_SYSCALL_BASE + 444)
+#define __NR_landlock_add_rule (__NR_SYSCALL_BASE + 445)
+#define __NR_landlock_restrict_self (__NR_SYSCALL_BASE + 446)
+#define __NR_process_mrelease (__NR_SYSCALL_BASE + 448)
+#define __NR_futex_waitv (__NR_SYSCALL_BASE + 449)
+#define __NR_set_mempolicy_home_node (__NR_SYSCALL_BASE + 450)
+#define __NR_cachestat (__NR_SYSCALL_BASE + 451)
+#define __NR_fchmodat2 (__NR_SYSCALL_BASE + 452)
+#define __NR_map_shadow_stack (__NR_SYSCALL_BASE + 453)
+#define __NR_futex_wake (__NR_SYSCALL_BASE + 454)
+#define __NR_futex_wait (__NR_SYSCALL_BASE + 455)
+#define __NR_futex_requeue (__NR_SYSCALL_BASE + 456)
 
 
 /*
@@ -461,7 +520,6 @@
 #define __ARGS_chmod			0
 #define __ARGS_lchown			0
 #define __ARGS_break			0
-
 #define __ARGS_lseek			0
 #define __ARGS_getpid			0
 #define __ARGS_mount			1
@@ -471,7 +529,6 @@
 #define __ARGS_stime			0
 #define __ARGS_ptrace			0
 #define __ARGS_alarm			0
-
 #define __ARGS_pause			0
 #define __ARGS_utime			0
 #define __ARGS_stty			0
@@ -502,7 +559,6 @@
 #define __ARGS_mpx			0
 #define __ARGS_setpgid			0
 #define __ARGS_ulimit			0
-
 #define __ARGS_umask			0
 #define __ARGS_chroot			0
 #define __ARGS_ustat			0
@@ -527,7 +583,6 @@
 #define __ARGS_setgroups		0
 #define __ARGS_select			0
 #define __ARGS_symlink			0
-
 #define __ARGS_readlink			0
 #define __ARGS_uselib			0
 #define __ARGS_swapon			0
@@ -552,8 +607,6 @@
 #define __ARGS_stat			0
 #define __ARGS_lstat			0
 #define __ARGS_fstat			0
-
-
 #define __ARGS_vhangup			0
 #define __ARGS_idle			0
 #define __ARGS_syscall			0
@@ -633,7 +686,6 @@
 #define __ARGS_capset			0
 #define __ARGS_sigaltstack		0
 #define __ARGS_sendfile			0
-
 #define __ARGS_vfork			0
 #define __ARGS_ugetrlimit		0
 #define __ARGS_mmap2			1
@@ -666,7 +718,6 @@
 #define __ARGS_mincore			0
 #define __ARGS_madvise			0
 #define __ARGS_fcntl64			0
-
 #define __ARGS_security			0
 #define __ARGS_gettid			0
 #define __ARGS_readahead		0
@@ -683,7 +734,6 @@
 #define __ARGS_lremovexattr		0
 #define __ARGS_fremovexattr		0
 #define __ARGS_tkill			0
-
 #define __ARGS_sendfile64		0
 #define __ARGS_futex			0
 #define __ARGS_sched_setaffinity	0
@@ -702,7 +752,6 @@
 #define __ARGS_set_thread_area		0
 #define __ARGS_get_thread_area		0
 #define __ARGS_set_tid_address		0
-
 #define __ARGS_timer_create		0
 #define __ARGS_timer_settime		0
 #define __ARGS_timer_gettime		0
@@ -717,7 +766,6 @@
 #define __ARGS_tgkill			0
 #define __ARGS_utimes			0
 #define __ARGS_arm_fadvise64_64		1
-
 #define __ARGS_fadvise64		0
 #define __ARGS_fadvise64_64		0
 #define __ARGS_pciconfig_iobase		0
@@ -730,7 +778,6 @@
 #define __ARGS_mq_notify		0
 #define __ARGS_mq_getsetattr		0
 #define __ARGS_waitid			0
-
 #define __ARGS_socket			0
 #define __ARGS_bind			0
 #define __ARGS_connect			0
@@ -759,7 +806,6 @@
 #define __ARGS_shmdt			0
 #define __ARGS_shmget			0
 #define __ARGS_shmctl			0
-
 #define __ARGS_add_key			1
 #define __ARGS_request_key		1
 #define __ARGS_keyctl			0
@@ -772,7 +818,6 @@
 #define __ARGS_mbind			1
 #define __ARGS_get_mempolicy		1
 #define __ARGS_set_mempolicy		1
-
 #define __ARGS_openat			0
 #define __ARGS_mkdirat			0
 #define __ARGS_mknodat			0
@@ -807,7 +852,6 @@
 #define __ARGS_fallocate		0
 #define __ARGS_timerfd_settime		0
 #define __ARGS_timerfd_gettime		0
-
 #define __ARGS_signalfd4		0
 #define __ARGS_eventfd2			0
 #define __ARGS_epoll_create1		0
@@ -833,7 +877,79 @@
 #define __ARGS_process_vm_writev	1
 #define __ARGS_kcmp			1
 #define __ARGS_finit_module		0
-
+#define __ARGS_sched_setattr		0
+#define __ARGS_sched_getattr		0
+#define __ARGS_renameat2		1
+#define __ARGS_seccomp			0
+#define __ARGS_getrandom		0
+#define __ARGS_memfd_create		0
+#define __ARGS_bpf			0
+#define __ARGS_execveat			1
+#define __ARGS_userfaultfd		0
+#define __ARGS_membarrier		0
+#define __ARGS_mlock2			0
+#define __ARGS_copy_file_range		1
+#define __ARGS_preadv2			1
+#define __ARGS_pwritev2			1
+#define __ARGS_pkey_mprotect		0
+#define __ARGS_pkey_alloc		0
+#define __ARGS_pkey_free		0
+#define __ARGS_statx			1
+#define __ARGS_rseq			0
+#define __ARGS_io_pgetevents		1
+#define __ARGS_migrate_pages		0
+#define __ARGS_kexec_file_load		0
+#define __ARGS_clock_gettime64		0
+#define __ARGS_clock_settime64		0
+#define __ARGS_clock_adjtime64		0
+#define __ARGS_clock_getres_time64	0
+#define __ARGS_clock_nanosleep_time64	0
+#define __ARGS_timer_gettime64		0
+#define __ARGS_timer_settime64		0
+#define __ARGS_timerfd_gettime64	0
+#define __ARGS_timerfd_settime64	0
+#define __ARGS_utimensat_time64		0
+#define __ARGS_pselect6_time64		1
+#define __ARGS_ppoll_time64		1
+#define __ARGS_io_pgetevents_time64	1
+#define __ARGS_recvmmsg_time64		1
+#define __ARGS_mq_timedsend_time64	1
+#define __ARGS_mq_timedreceive_time64	1
+#define __ARGS_semtimedop_time64	0
+#define __ARGS_rt_sigtimedwait_time64	0
+#define __ARGS_futex_time64		1
+#define __ARGS_sched_rr_get_interval_time64 0
+#define __ARGS_pidfd_send_signal	0
+#define __ARGS_io_uring_setup		0
+#define __ARGS_io_uring_enter		1
+#define __ARGS_io_uring_register	0
+#define __ARGS_open_tree		0
+#define __ARGS_move_mount		1
+#define __ARGS_fsopen			0
+#define __ARGS_fsconfig			1
+#define __ARGS_fsmount			0
+#define __ARGS_fspick			0
+#define __ARGS_pidfd_open		0
+#define __ARGS_clone3			0
+#define __ARGS_openat2			0
+#define __ARGS_pidfd_getfd		0
+#define __ARGS_faccessat2		0
+#define __ARGS_process_madvise		1
+#define __ARGS_epoll_pwait2		1
+#define __ARGS_mount_setattr		1
+#define __ARGS_quotactl_fd		0
+#define __ARGS_landlock_create_ruleset	0
+#define __ARGS_landlock_add_rule	0
+#define __ARGS_landlock_restrict_self	0
+#define __ARGS_process_mrelease		0
+#define __ARGS_futex_waitv		1
+#define __ARGS_set_mempolicy_home_node	0
+#define __ARGS_cachestat 0
+#define __ARGS_fchmodat2 0
+#define __ARGS_map_shadow_stack 0
+#define __ARGS_futex_wake 0
+#define __ARGS_futex_wait 1
+#define __ARGS_futex_requeue 0
 
 #ifdef __ASSEMBLER__
 
